@@ -79,7 +79,7 @@ class MessageBody:
                         device = mapentry["device"]
                         stateName = mapentry["stateName"]
 
-                        _LOGGER.debug("SettingValueState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
+                        _LOGGER.debug("id:'{0}', name:'{1}', [SettingValueState] device_type:'{2}' state_name:'{3}'".format(device.id, device.name, device.device_type, mapentry["stateName"]))
 
                         device.set_value(stateName, dval)
 
