@@ -26,6 +26,7 @@ class Miniserver:
 
     def __init__(self, host=None, port=None, username=None, password=None, publickey=None, privatekey=None, key=None, iv=None):
         """Initialize Miniserver class."""
+        _LOGGER.debug("__init__")
         self.host = host
         self.port = port
         self.username = username
@@ -34,7 +35,8 @@ class Miniserver:
         self.message_body = None
         self.client_salt_count = 0
         self.client_salt = self.generate_client_salt()
-        self.public_key = RSA.importKey(publickey)
+        #self.public_key = RSA.importKey(publickey)
+        self.public_key = self.get_publickey(publickey)
         self.private_key = privatekey
         self.key = key
         self.iv = iv
@@ -44,7 +46,7 @@ class Miniserver:
 
     def connect(self, loop, connection_status):
         """Connect to the miniserver."""
-        _LOGGER.debug("connect v0.0.42")
+        _LOGGER.debug("connect v0.0.45")
         from .wsclient import WSClient
         self.loop = loop
         self.async_connection_status_callback = connection_status
@@ -96,18 +98,18 @@ class Miniserver:
             elif "getkey2" in self.message_body.control:
                 _LOGGER.debug('PROCESS getkey2 response')
                 self.server_key = self.message_body.msg["LL"]["value"]["key"]
-                #_LOGGER.debug("  server_key: {0} {1}".format(type(self.server_key), self.server_key))
+                _LOGGER.debug("  server_key: {0} {1}".format(type(self.server_key), self.server_key))
                 self.server_salt = self.message_body.msg["LL"]["value"]["salt"]
-                #_LOGGER.debug("  server_salt: {0} {1}".format(type(self.server_salt), self.server_salt))
+                _LOGGER.debug("  server_salt: {0} {1}".format(type(self.server_salt), self.server_salt))
 
-                #_LOGGER.debug('  Hash user password')
+                _LOGGER.debug('  Hash user password')
                 hash_sha = SHA1.new()
                 hash_sha.update(bytes('{0}:{1}'.format(
                     self.password,
                     self.server_salt),'utf-8'))
                 pwhash = hash_sha.hexdigest().upper()
 
-                #_LOGGER.debug('  Hash credential')
+                _LOGGER.debug('  Hash credential')
                 hash_hmac = HMAC.new(binascii.a2b_hex(self.server_key), digestmod=SHA1)
                 hash_hmac.update(bytes('{0}:{1}'.format(
                     self.username,
@@ -175,29 +177,29 @@ class Miniserver:
         cipher_aes = AES.new(key, AES.MODE_CBC, iv)
 
         length = len(salted_command)
-        #_LOGGER.debug("  length: {0} {1}".format(type(length), length))
+        _LOGGER.debug("  length: {0} {1}".format(type(length), length))
         padding_len = AES.block_size - (length % AES.block_size)
-        #_LOGGER.debug("  padding_len: {0} {1}".format(type(padding_len), padding_len))
+        _LOGGER.debug("  padding_len: {0} {1}".format(type(padding_len), padding_len))
         padding = "\x00" * padding_len
-        #_LOGGER.debug("  salted_command: {0} {1}".format(type(salted_command), salted_command))
-        #_LOGGER.debug("  padding: {0} {1}".format(type(padding), padding))
+        _LOGGER.debug("  salted_command: {0} {1}".format(type(salted_command), salted_command))
+        _LOGGER.debug("  padding: {0} {1}".format(type(padding), padding))
         padded_salted_command = salted_command + padding
 
-        #enc_cmd_part = cipher_aes.encrypt(pad(salted_command.encode('utf8'), AES.block_size))
+        enc_cmd_part = cipher_aes.encrypt(pad(salted_command.encode('utf8'), AES.block_size))
         enc_cmd_part = cipher_aes.encrypt(bytes(padded_salted_command, 'utf-8'))
-        #_LOGGER.debug("  enc_cmd_part: {0} {1}".format(type(enc_cmd_part), enc_cmd_part))
+        _LOGGER.debug("  enc_cmd_part: {0} {1}".format(type(enc_cmd_part), enc_cmd_part))
 
         b64enc = b64encode(enc_cmd_part)
-        #_LOGGER.debug("  b64enc: {0} {1}".format(type(b64enc), b64enc))
+        _LOGGER.debug("  b64enc: {0} {1}".format(type(b64enc), b64enc))
 
         #b64enc_quote = utils.quote(b64encode(enc_cmd_part))
-        #_LOGGER.debug("  b64enc_quote: {0} {1}".format(type(b64enc_quote), b64enc_quote))
+        _LOGGER.debug("  b64enc_quote: {0} {1}".format(type(b64enc_quote), b64enc_quote))
 
         urlencoded = urllib.parse.quote(b64enc, safe='')
-        #_LOGGER.debug("  urlencoded: {0} {1}".format(type(urlencoded), urlencoded))
+        _LOGGER.debug("  urlencoded: {0} {1}".format(type(urlencoded), urlencoded))
 
         encrypted_command = "jdev/sys/fenc/{0}".format(urlencoded) #.encode('utf8')
-        #_LOGGER.debug("  encrypted_command: {0}".format(encrypted_command))
+        _LOGGER.debug("  encrypted_command: {0}".format(encrypted_command))
 
         return encrypted_command
     
@@ -222,9 +224,13 @@ class Miniserver:
         return str(r,'utf8')
 
     def generate_client_salt(self):
-        #_LOGGER.debug("Generate Client Salt")
+        _LOGGER.debug("Generate Client Salt")
         self.client_salt_count = self.client_salt_count + 1
         salt = format(str(self.client_salt_count), "a>4s") + "123e"
         #salt = "123e"
         _LOGGER.debug("  salt = " + salt)
-        return salt
\ No newline at end of file
+        return salt
+
+    def get_publickey(self, publickey):
+        _LOGGER.debug("Get PublicKey")
+        return RSA.importKey(publickey)
\ No newline at end of file
